@@ -146,11 +146,17 @@ class DBConnect():
                     if filtered_value[i].strip() != '':
                         find_dict[columns[i]] = {'$regex': filtered_value[i]}
                 # 整理请求参数中的筛排序列表
+                if type(sort_order[i]) != str:
+                    abort(Response('计算组件分页参数异常: 排序参数不支持 int 类型', 400, {}))
                 sort_value = sort_order[i].strip()
                 if sort_value == 'asc':
                     sort_list.append((columns[i], pymongo.ASCENDING))
                 elif sort_value == 'desc':
                     sort_list.append((columns[i], pymongo.DESCENDING))
+                elif sort_value == '':
+                    pass
+                else:
+                    abort(Response('计算组件分页参数异常: 仅支持 asc 和 desc 两个值', 400, {}))
         # 仅存在日期查询区间参数时，进行额外的创建时间区间查询
         if start_date and end_date:
             find_dict['creation_time'] = {
@@ -159,7 +165,7 @@ class DBConnect():
         records_filtered = find_data.count()
         if not records_filtered:
             return {
-                'records_total': 0,
+                'records_total': self.mongo_collection.estimated_document_count(),
                 'records_filtered': 0,
                 'query_result': [],
                 'total_pages': 0,
