@@ -22,9 +22,9 @@ def handle_date(date: str, date_type='start') -> datetime:
         if date_type == 'end' and date_data:
             date_data += timedelta(hours=23, minutes=59, seconds=59)
     except Exception as err:
-        date_data = None
-        logging.warning('日期字符串解析异常: {0}'.format(err))
-    return date_data
+        str_data = '日期字符串解析异常: {0}'.format(err)
+        logging.warning(str_data)
+        abort(Response(str_data, 400, {}))
 
 
 def handle_db_to_list(db_cursor: Cursor) -> list:
